/*
 * parse.c --- parse configuration file for vs1000d
 */

#include <stdio.h>
#include <unistd.h>
#include <stdlib.h>
#include <ctype.h>
#include <string.h>
#include "vs1000.h"
#include "vs1000d.h"

char *boot_file = 0;

struct vs_box_config box_config[MAX_BOX_NUM+1];
int num_box_config = 0;

/*
 * Parse an ethernet address.  Return -1 on error, 0 for success.
 */
static int parse_ether_addr(const char *str, unsigned char addr[6])
{
	int	a, b, c, d, e, f;
	
	if (sscanf(str, "%2x:%2x:%2x:%2x:%2x:%2x", &a, &b, &c,
		   &d, &e, &f) != 6)
		return -1;
	addr[0] = a;
	addr[1] = b;
	addr[2] = c;
	addr[3] = d;
	addr[4] = e;
	addr[5] = f;
	return 0;
}

/*
 * Print an ethernet address
 */
char *sprint_ether_addr(unsigned char addr[6])
{
	static char buf[40];

	sprintf(buf, "%02x:%02x:%02x:%02x:%02x:%02x", addr[0], addr[1],
		addr[2], addr[3], addr[4], addr[5]);
	return buf;
}

/*
 * Return a copy of a string using allocated memory.
 */
char *dup_string(const char *s)
{
	char *str;

	str = malloc(strlen(s)+1);
	if (str)
		strcpy(str, s);
	return str;
}

void parse_config(const char *cfg_filename)
{
	FILE	*f;
	char	line[256], buf[256], *cp;
	char	arg1[80], arg2[80], arg3[80];
	int	argc;
	struct vs_box_config *cfg;
	int	line_num = 0;
	
	f = fopen(cfg_filename, "r");
	if (!f) {
		perror("fopen");
		exit(1);
	}
	while (!feof(f)) {
		if (!fgets(line, sizeof(line), f))
			break;
		line_num++;
		line[sizeof(line)-1] = 0;
		strcpy(buf, line);
		cp = strchr(buf, '\n');
		if (cp)
			*cp = '\0';
		cp = strchr(buf, '#');
		if (cp)
			*cp = '\0';
		arg1[0] = arg2[0] = arg3[0] = 0;
		argc = sscanf(buf, "%s %s %s", arg1, arg2, arg3);
		if (argc <= 0)
			continue;

		if ((argc == 2) && 
		    (strcmp(arg1, "bootfile") == 0)) {
			if (*arg2 == '\0')
				fprintf(stderr,
					"Missing bootfile in line #%d\n", 
					line_num);
			else
				boot_file = dup_string(arg2);
			continue;
		}

		cfg = box_config + num_box_config;
		if ((argc < 2) || parse_ether_addr(arg1, cfg->ether_addr)) {
			fprintf(stderr, "Syntax error in line #%d\n",
				line_num);
			continue;
		}
		strncpy(cfg->interface, arg2, sizeof(cfg->interface));
		cfg->interface[sizeof(cfg->interface-1)] = '\0';
		    
		if (argc < 3)
			cfg->num_lines = 16;
		else
			cfg->num_lines = atoi(arg3);

		num_box_config++;
		if (num_box_config > MAX_BOX_NUM) {
			fprintf(stderr, "Too many VS-1000 boxes listed "
				"in the configuration file.\n");
			fprintf(stderr, "VS-1000 at %s ignored.\n", arg1);
			num_box_config--;
			continue;
		}
	}
	fclose(f);
}

void debug_print_config()
{
	int	i;
	
        if (boot_file)
		printf("Boot file is %s\n", boot_file);
	else
		printf("No boot file specified.\n");

	for (i=0; i < num_box_config; i++) {
		printf("Box #%d: addr=%s, interface=%s, num_ports=%d\n", i+1,
		       sprint_ether_addr(box_config[i].ether_addr),
		       box_config[i].interface,
		       box_config[i].num_lines);
	}
}

