#!/bin/sh
#
# This script is responsible for installing the VS-1000 driver
#

if [ `whoami` != root ]; then
	echo "You must be root to install the device driver!"
	exit 1
fi

#
# Check to see whether or not mod_rocket.o was built; if it wasn't built,
# we don't need to install it.
#
if [ -f mod_vs1000.o ]; then
	OBJS="mod_vs1000.o vs1000.o"
else
	OBJS=vs1000.o
fi

# Install a copy of the driver in the version independent location
if [ ! -d /lib/modules ]; then 
	mkdir -p /lib/modules
fi

cp $OBJS /lib/modules

# Install a copy of the driver in a kernel version specific location
if [ -f .kver ]; then
    KVER=`cat .kver`;
else
    KVER=`grep UTS_RELEASE /usr/include/linux/version.h | \
	awk '{print $3}' | tr -d \"`
fi
RVER=`uname -r`
echo " "
echo "Installing VS-1000 driver for Linux $KVER"
echo " "
if [ $KVER != $RVER ]; then
    echo "WARNING: The current kernel is actually version $RVER."
    echo " "
fi

#
# Actually install the kernel modules
#
if [ ! -d /lib/modules/$KVER/misc ]; then 
	mkdir -p /lib/modules/$KVER/misc
fi

cp $OBJS /lib/modules/$KVER/misc

#
# If the modules version wasn't built, remove it from the install tree, 
# lest we get led astray
# 
if [ ! -f mod_vs1000.o ]; then
    rm -f /lib/modules/mod_vs1000.o /lib/modules/$KVER/misc/mod_vs1000.o
fi

#
# OK, now we install the boot script 
#
if [ -d /etc/rc.d/init.d ]; then 
	# This is a RedHat or other system using a System V init scheme
	if [ ! -f /etc/rc.d/init.d/vs1000 ]; then
		echo "You are using a system which uses the System V init"
		echo "scheme.  The initialization script has been installed"
		echo "in /etc/rc.d/init.d and it has been automatically "
		echo "set up to be run when you reboot"

		ln -sf ../init.d/vs1000 /etc/rc.d/rc2.d/S83vs1000
		ln -sf ../init.d/vs1000 /etc/rc.d/rc3.d/S83vs1000
		ln -sf ../init.d/vs1000 /etc/rc.d/rc5.d/S83vs1000
		ln -sf ../init.d/vs1000 /etc/rc.d/rc0.d/K18vs1000
		ln -sf ../init.d/vs1000 /etc/rc.d/rc1.d/K18vs1000
		ln -sf ../init.d/vs1000 /etc/rc.d/rc6.d/K18vs1000
	fi
	cp rc.vs1000 /etc/rc.d/init.d/vs1000
elif [ -d /etc/init.d ]; then 
	# This is a Debian system
	if [ ! -f /etc/init.d/vs1000 ]; then
		echo "You are using a system which uses the Debian "
		echo "System V init directory layout.  The initialization"
		echo "script has been installed in /etc/init.d and it"
		echo "has been automatically set up to be run when you reboot"

		ln -sf ../init.d/vs1000 /etc/rc2.d/S83vs1000
		ln -sf ../init.d/vs1000 /etc/rc3.d/S83vs1000
		ln -sf ../init.d/vs1000 /etc/rc5.d/S83vs1000
		ln -sf ../init.d/vs1000 /etc/rc0.d/K20vs1000
		ln -sf ../init.d/vs1000 /etc/rc1.d/K20vs1000
		ln -sf ../init.d/vs1000 /etc/rc6.d/K20vs1000
	fi
	cp rc.vs1000 /etc/init.d/vs1000
else
	if [ ! -f /etc/rc.d/rc.vs1000 ]; then
		echo "The initialization script has been installed in "
		echo "/etc/rc.d/rc.vs1000.  You will need to edit your "
		echo "/etc/rc files to run /etc/rc.d/rc.vs1000"

		if [ ! -d /etc/rc.d ]; then 
			mkdir -p /etc/rc.d
		fi

		cp rc.vs1000 /etc/rc.d
	fi
fi

#
# Copy in the vs1000.conf file, if isn't already installed
#
if [ ! -f /etc/vs1000.conf ]; then
	cp vs1000.conf /etc
	echo "Make sure you check and edit the /etc/vs1000.conf file!"
fi

#
# Install the vs1000 microcode file
#
cp vs1000.bin /etc/vs1000.bin

#
# Install vs1000d
#
if [ -f /sbin/vs1000d ] ; then
    mv /sbin/vs1000d /sbin/vs1000d.old
fi
cp vs1000d /sbin/vs1000d
strip /sbin/vs1000d
chmod 755 /sbin/vs1000d
rm -f /sbin/vs1000d.old

